aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-ncp.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2017-01-09 22:18:49 -0800
committerGuy Harris <guy@alum.mit.edu>2017-01-10 06:19:37 +0000
commit7cd6906056922e4b8f68f1216d94eaa0809896fe (patch)
tree5a8c793f188ddda7f36a50369d00ff0de8f563e5 /epan/dissectors/packet-ncp.c
parent2a3b2360e15d49defde55240a5c1e171c7cade89 (diff)
Rename tvb_new_subset() to tvb_new_subset_length_caplen().
This emphasizes that there is no such thing as *the* routine to construct a subset tvbuff; you need to choose one of tvb_new_subset_remaining() (if you want a new tvbuff that contains everything past a certain point in an existing tvbuff), tvb_new_subset_length() (if you want a subset that contains everything past a certain point, for some number of bytes, in an existing tvbuff), and tvb_new_subset_length_caplen() (for all other cases). Many of the calls to tvb_new_subset_length_caplen() should really be calling one of the other routines; that's the next step. (This also makes it easier to find the calls that need fixing.) Change-Id: Ieb3d676d8cda535451c119487d7cd3b559221f2b Reviewed-on: https://code.wireshark.org/review/19597 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/dissectors/packet-ncp.c')
-rw-r--r--epan/dissectors/packet-ncp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-ncp.c b/epan/dissectors/packet-ncp.c
index 6be77b86de..67aadbdfda 100644
--- a/epan/dissectors/packet-ncp.c
+++ b/epan/dissectors/packet-ncp.c
@@ -1263,7 +1263,7 @@ dissect_ncp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
} else {
/*
* XXX - do this by using -1 and -1 as the length
* arguments to "tvb_new_subset()" and then calling
* "tvb_set_reported_length()"? That'll throw an
* exception if "data_len" goes past the reported
* length of the packet, but that's arguably a
@@ -1273,7 +1273,7 @@ dissect_ncp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
if (length_remaining > data_len)
length_remaining = data_len;
if (data_len != 0) {
- call_data_dissector(tvb_new_subset(tvb, offset,
+ call_data_dissector(tvb_new_subset_length_caplen(tvb, offset,
length_remaining, data_len),
pinfo, ncp_tree);
}
@@ -1263,7 +1263,7 @@ dissect_ncp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
/*
* XXX - do this by using -1 and -1 as the length
- * arguments to "tvb_new_subset()" and then calling
+ * arguments to "tvb_new_subset_length_caplen()" and then calling
* "tvb_set_reported_length()"? That'll throw an
* exception if "data_len" goes past the reported